@@ -4,7 +4,14 @@ from base64 import b64decode, b64encode
 
 import httpx
 
-from .settings import API_URL, APPLICATION_ID, CLIENT_SECRET, DEFAULT_IP_ADDRESS, CLIENT_ID, MERCHANT_UID
+from .settings import (
+    API_URL,
+    APPLICATION_ID,
+    CLIENT_SECRET,
+    DEFAULT_IP_ADDRESS,
+    CLIENT_ID,
+    MERCHANT_UID,
+)
 from .adumo_types import AccountHolder, Card
 
 from .constants import FAILED, SUCCESS
@@ -38,7 +45,11 @@ class Adumo:
         return access_token
 
     def check_3d_enrollment(
-        self, account_holder: AccountHolder, card: Card, amount: str, ip_address: str = None
+        self,
+        account_holder: AccountHolder,
+        card: Card,
+        amount: str,
+        ip_address: str = None,
     ):
         if ip_address is None:
             ip_address = DEFAULT_IP_ADDRESS
@@ -87,9 +98,7 @@ class Adumo:
             }
 
         if not three_d_secure_enrolled:
-            logger.error(
-                f"[Creditcard] Card not enrolled in 3ds"
-            )
+            logger.error(f"[Creditcard] Card not enrolled in 3ds")
             return {
                 "status": FAILED,
                 "transaction_id": transaction_id,
@@ -111,7 +120,7 @@ class Adumo:
 
         try:
             self._authenticate(pares, md)
-        except CreditCardProcessor3dsFailure():
+        except Exception:
             return {"status": FAILED, "transaction_id": transaction_id}
 
         result = self._authorise_and_settle(
@@ -126,6 +135,7 @@ class Adumo:
         result = httpx.post(url, json=request, headers=self.headers)
 
         response_dict = self._process_response(result)
+
         logger.info(
             f"[CreditCard] Authenticate 3ds response {response_dict.get('errorNo')} - "
             f"{response_dict.get('errorMsg')}"
@@ -172,6 +182,7 @@ class Adumo:
     @staticmethod
     def _process_response(response):
         response_dict = response.json()
+        logger.info(f'[Creditcard] {response=response_dict}')
         status_code = response_dict.get("statusCode")
 
         if status_code and status_code != 200:
